@@ -1,6 +1,6 @@
-/* (C)opyright MMVI-MMVII Anselm R. Garbe <garbeam at gmail dot com>
- * See LICENSE file for license details.
- */
+/* © 2006-2007 Anselm R. Garbe <garbeam at gmail dot com>
+ * © 2006-2007 Sander van Dijk <a dot h dot vandijk at gmail dot com>
+ * See LICENSE file for license details. */
 #include "dwm.h"
 #include <stdarg.h>
 #include <stdio.h>
@@ -30,12 +30,12 @@ eprint(const char *errstr, ...) {
 }
 
 void
-spawn(Arg *arg) {
+spawn(const char *arg) {
 	static char *shell = NULL;
 
 	if(!shell && !(shell = getenv("SHELL")))
 		shell = "/bin/sh";
-	if(!arg->cmd)
+	if(!arg)
 		return;
 	/* The double-fork construct avoids zombie processes and keeps the code
 	 * clean from stupid signal handlers. */
@@ -44,8 +44,8 @@ spawn(Arg *arg) {
 			if(dpy)
 				close(ConnectionNumber(dpy));
 			setsid();
-			execl(shell, shell, "-c", arg->cmd, (char *)NULL);
-			fprintf(stderr, "dwm: execl '%s -c %s'", shell, arg->cmd);
+			execl(shell, shell, "-c", arg, (char *)NULL);
+			fprintf(stderr, "dwm: execl '%s -c %s'", shell, arg);
 			perror(" failed");
 		}
 		exit(0);
